%
disp(' ');
disp('  peaks_sigma.m  ver 1.0  December 4, 2012 ');
disp('  by Tom Irvine ');
disp(' ');
disp('  This script counts the number of absolute peaks above a ');
disp('  a user-specified sigma level. ');
%
disp(' ')
disp(' The input time history must have two columns: time(sec) & amplitude')
disp(' ')
%
close all;
%
clear a;
clear y;
clear length;
%
[t,y,dt,sr,tmx,tmi,n,ncontinue]=enter_time_history();
%
y = detrend(y,'constant');  % remove mean
%
mu=mean(y);
sd=std(y);
mx=max(y);
mi=min(y);
rms=sqrt(sd^2+mu^2);
disp(' ')
disp(' Amplitude Stats ')
out0 = sprintf(' number of points = %d ',n);
out1 = sprintf(' mean = %8.4g    std = %8.4g    rms = %8.4g ',mu,sd,rms);
out2a = sprintf(' max  = %9.4g    ',mx);
out2b = sprintf(' min  = %9.4g  \n',mi);
disp(out0);
disp(out1);
disp(out2a);
disp(out2b);
%
%
[v]=differentiate_function(y,dt);
rf=(std(v)/sd)/(2*pi);
%
out1=sprintf('\n Rice Characteristic Frequency = %8.4g Hz ',rf);
disp(out1);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
figure(1);
plot(t,y);
grid on;
xlabel('Time(sec)');
ylabel('Amplitude');
%
m=length(y)-1;
%
disp(' Begin slope calculation ')
k=1;
for i=2:m
     slope1=(  y(i)-y(i-1));
     slope2=(y(i+1)-y(i));
     if(slope1>0. && slope2<0. && y(i)>0)
          a(k)=y(i);
          k=k+1;
     end
     if(slope1<0. && slope2>0. && y(i)<0)
          a(k)=y(i);
          k=k+1;
     end     
end
%
a=abs(a);
%
k=length(a);
%
out1=sprintf('\n %d total peaks ',k);
disp(out1);
%
out2=sprintf('\n maximum peak = %6.3g-sigma',max(a)/sd);
disp(out2);
%    
while(1)
%
    disp(' ');
    level=input(' Enter the sigma level (example 3 for 3-sigma): ');
%
    n_sigma=level*sd;
%
    num=0;
    for i=1:k;
        if(a(i)>n_sigma)
            num=num+1;
        end
    end
%
    if(num==1)
        out1=sprintf('\n 1 peak > %6.3g-sigma ',level);
    else
        out1=sprintf('\n %d peaks > %6.3g-sigma ',num,level);     
    end
    disp(out1);
%
    out2=sprintf('\n   %5.3g percent ',(num/k)*100);
    disp(out2);
%
    disp(' ');
    disp(' Perform another case with this data?  1=yes 2=no ');
    ic=input(' ');
    if(ic==2)
        break;
    end
%
end